<?php

namespace Litecms\Leveluserrank\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Leveluserrank\Http\Requests\LeveluserrankRequest;
use Litecms\Leveluserrank\Interfaces\LeveluserrankRepositoryInterface;
use Litecms\Leveluserrank\Models\Leveluserrank;

/**
 * Resource controller class for leveluserrank.
 */
class LeveluserrankResourceController extends BaseController
{

    /**
     * Initialize leveluserrank resource controller.
     *
     * @param type LeveluserrankRepositoryInterface $leveluserrank
     *
     * @return null
     */
    public function __construct(LeveluserrankRepositoryInterface $leveluserrank)
    {
        parent::__construct();
        $this->repository = $leveluserrank;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Leveluserrank\Repositories\Criteria\LeveluserrankResourceCriteria::class);
    }

    /**
     * Display a list of leveluserrank.
     *
     * @return Response
     */
    public function index(LeveluserrankRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Leveluserrank\Repositories\Presenter\LeveluserrankPresenter::class)
                ->$function();
        }

        $leveluserrank_s = $this->repository->paginate();

        return $this->response->title(trans('leveluserrank::leveluserrank.names'))
            ->view('leveluserrank::leveluserrank.index', true)
            ->data(compact('leveluserrank_s'))
            ->output();
    }

    /**
     * Display leveluserrank.
     *
     * @param Request $request
     * @param Model   $leveluserrank
     *
     * @return Response
     */
    public function show(LeveluserrankRequest $request, Leveluserrank $leveluserrank)
    {

        if ($leveluserrank->exists) {
            $view = 'leveluserrank::leveluserrank.show';
        } else {
            $view = 'leveluserrank::leveluserrank.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('leveluserrank::leveluserrank.name'))
            ->data(compact('leveluserrank'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new leveluserrank.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LeveluserrankRequest $request)
    {

        $leveluserrank = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('leveluserrank::leveluserrank.name')) 
            ->view('leveluserrank::leveluserrank.create', true) 
            ->data(compact('leveluserrank'))
            ->output();
    }

    /**
     * Create new leveluserrank.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LeveluserrankRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $leveluserrank                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('leveluserrank::leveluserrank.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('leveluserrank/leveluserrank/' . $leveluserrank->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/leveluserrank/leveluserrank'))
                ->redirect();
        }

    }

    /**
     * Show leveluserrank for editing.
     *
     * @param Request $request
     * @param Model   $leveluserrank
     *
     * @return Response
     */
    public function edit(LeveluserrankRequest $request, Leveluserrank $leveluserrank)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('leveluserrank::leveluserrank.name'))
            ->view('leveluserrank::leveluserrank.edit', true)
            ->data(compact('leveluserrank'))
            ->output();
    }

    /**
     * Update the leveluserrank.
     *
     * @param Request $request
     * @param Model   $leveluserrank
     *
     * @return Response
     */
    public function update(LeveluserrankRequest $request, Leveluserrank $leveluserrank)
    {
        try {
            $attributes = $request->all();

            $leveluserrank->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('leveluserrank::leveluserrank.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('leveluserrank/leveluserrank/' . $leveluserrank->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leveluserrank/leveluserrank/' . $leveluserrank->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the leveluserrank.
     *
     * @param Model   $leveluserrank
     *
     * @return Response
     */
    public function destroy(LeveluserrankRequest $request, Leveluserrank $leveluserrank)
    {
        try {

            $leveluserrank->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('leveluserrank::leveluserrank.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('leveluserrank/leveluserrank/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leveluserrank/leveluserrank/' . $leveluserrank->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple leveluserrank.
     *
     * @param Model   $leveluserrank
     *
     * @return Response
     */
    public function delete(LeveluserrankRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('leveluserrank::leveluserrank.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('leveluserrank/leveluserrank'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/leveluserrank/leveluserrank'))
                ->redirect();
        }

    }

    /**
     * Restore deleted leveluserrank_s.
     *
     * @param Model   $leveluserrank
     *
     * @return Response
     */
    public function restore(LeveluserrankRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('leveluserrank::leveluserrank.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/leveluserrank/leveluserrank'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/leveluserrank/leveluserrank/'))
                ->redirect();
        }

    }

}
