<?php

namespace Litecms\Leveluserrank\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Leveluserrank\Models\Leveluserrank;

class LeveluserrankPolicy
{

    /**
     * Determine if the given user can view the leveluserrank.
     *
     * @param UserPolicy $user
     * @param Leveluserrank $leveluserrank
     *
     * @return bool
     */
    public function view(UserPolicy $user, Leveluserrank $leveluserrank)
    {
        if ($user->canDo('leveluserrank.leveluserrank.view') && $user->isAdmin()) {
            return true;
        }

        return $leveluserrank->user_id == user_id() && $leveluserrank->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leveluserrank.
     *
     * @param UserPolicy $user
     * @param Leveluserrank $leveluserrank
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('leveluserrank.leveluserrank.create');
    }

    /**
     * Determine if the given user can update the given leveluserrank.
     *
     * @param UserPolicy $user
     * @param Leveluserrank $leveluserrank
     *
     * @return bool
     */
    public function update(UserPolicy $user, Leveluserrank $leveluserrank)
    {
        if ($user->canDo('leveluserrank.leveluserrank.edit') && $user->isAdmin()) {
            return true;
        }

        return $leveluserrank->user_id == user_id() && $leveluserrank->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leveluserrank.
     *
     * @param UserPolicy $user
     * @param Leveluserrank $leveluserrank
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Leveluserrank $leveluserrank)
    {
        return $leveluserrank->user_id == user_id() && $leveluserrank->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leveluserrank.
     *
     * @param UserPolicy $user
     * @param Leveluserrank $leveluserrank
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Leveluserrank $leveluserrank)
    {
        if ($user->canDo('leveluserrank.leveluserrank.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leveluserrank.
     *
     * @param UserPolicy $user
     * @param Leveluserrank $leveluserrank
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Leveluserrank $leveluserrank)
    {
        if ($user->canDo('leveluserrank.leveluserrank.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
